{% macro pagination() %}
{% if page %} {% for n in previous_pages %} {% if n is none %} ... {% else %} {{ n }} {% endif %} {% endfor %} {% endif %} {% if more_commits %} »» {% elif page %} »» {% endif%}
{% endmacro %}

## {% if subpaths %} History of {% for name, subpath in subpaths %} {{ name }} {% if not loop.last %} / {% endif %} {% endfor %} {% else %} Commit History {% endif %} @{{ rev }} {% if USE_SMARTHTTP %} `git clone {{ url_for('index', repo=repo.name, namespace=namespace, _external=True) }}` {% endif %} {% if repo.cloneurl %} `git clone {{ repo.cloneurl }}` {% endif %}

{{ pagination() }}

{% for commit in history %}
- {{ commit.message|force_unicode|shorten_message }} {{ commit.author|force_unicode|extract_author_name }} {% if commit.author != commit.committer %} (commit: {{ commit.committer|force_unicode|extract_author_name }}) {% endif %} {{ commit.commit_time|timesince }}
{% endfor %}

{{ pagination() }}